<?php

class SwpmStripeBuyNowIpnHandler {
	
	var $stripe_published_key_live;
	var $stripe_secret_key_live;
	var $stripe_published_key_test;
	var $stripe_secret_key_test;
	var $sandbox_mode = false;
	
	public function __construct() {
			
		$wcfm_membership_options = get_option( 'wcfm_membership_options', array() );
		$membership_payment_settings = array();
		if( isset( $wcfm_membership_options['membership_payment_settings'] ) ) $membership_payment_settings = $wcfm_membership_options['membership_payment_settings'];
		$this->stripe_published_key_live = isset( $membership_payment_settings['stripe_published_key_live'] ) ? $membership_payment_settings['stripe_published_key_live'] : '';
		$this->stripe_secret_key_live = isset( $membership_payment_settings['stripe_secret_key_live'] ) ? $membership_payment_settings['stripe_secret_key_live'] : '';
		$this->stripe_published_key_test = isset( $membership_payment_settings['stripe_published_key_test'] ) ? $membership_payment_settings['stripe_published_key_test'] : '';
		$this->stripe_secret_key_test = isset( $membership_payment_settings['stripe_secret_key_test'] ) ? $membership_payment_settings['stripe_secret_key_test'] : '';
		$this->sandbox_mode = isset( $membership_payment_settings['paypal_sandbox'] ) ? true : false;
		
		$this->handle_stripe_ipn();
	}
	
	public function handle_stripe_ipn(){
		global $WCFM, $WCFMvm, $wpdb;
		
		wcfmvm_create_log("Stripe Buy Now IPN received. Processing request...");
		
		//Include the Stripe library.
		include( $WCFMvm->plugin_path . 'includes/libs/stripe-gateway/init.php');
		
		//Read and sanitize the request parameters.
		$membership_id = sanitize_text_field($_REQUEST['item_number']);
		$membership_id = absint($membership_id);
		$button_title = sanitize_text_field($_REQUEST['item_name']);
		
		$stripe_token = sanitize_text_field($_POST['stripeToken']);
		$stripe_token_type = sanitize_text_field($_POST['stripeTokenType']);
		$stripe_email = sanitize_email($_POST['stripeEmail']);
			
		//Retrieve the CPT for this button
		$button_cpt = get_post($membership_id); 
		if(!$button_cpt){
			//Fatal error. Could not find this payment button post object.
			wcfmvm_create_log("Fatal Error! Failed to retrieve the membership post object for the given Membership ID: ". $membership_id);
			wp_die("Fatal Error! Membership (ID: ".$membership_id.") does not exist. This request will fail.");
		}
		
		$subscription = (array) get_post_meta( $membership_id, 'subscription', true );
		$plan_id = isset( $subscription['stripe_plan_id'] ) ? $subscription['stripe_plan_id'] : '';
    $descr = 'Subscription to "' . $plan_id . '" plan';
			
		//Validation passed. Go ahead with the charge.
		
		//Sandbox and other settings
		if( $this->sandbox_mode ) {
			wcfmvm_create_log("Sandbox payment mode is enabled. Using test API key details.");
			$secret_key = $this->stripe_secret_key_test; //Use sandbox API key
		} else {
			$secret_key = $this->stripe_secret_key_live; //Use live API key
		}

		//Set secret API key in the Stripe library
		\Stripe\Stripe::setApiKey($secret_key);
		
		// Get the credit card details submitted by the form
		$token = $stripe_token;
		
		// Create the charge on Stripe's servers - this will charge the user's card
		try {
			$customer = \Stripe\Customer::create(array(
									'description' => $descr,
									'email' => $stripe_email,
									'source' => $token,
									'plan' => $plan_id,
			));
		} catch (Exception $e) {
			wcfmvm_create_log( "Error occured during Stripe Subscribe. " . $e->getMessage() );
			$body = $e->getJsonBody();
			$error = $body['error'];
			$error_string = print_r($error, true);
			wcfmvm_create_log( "Error details: " . $error_string );
			wp_die("Stripe Subscription Error! " . $e->getMessage() . $error_string);
		}

		//Everything went ahead smoothly with the charge.
		wcfmvm_create_log("Stripe Subscription successful.");
		
		//let's add button_id to metadata
		$customer->metadata = array('membership_id' => $membership_id);
		try {
			$customer->save();
		} catch (Exception $e) {
			wcfmvm_create_log("Error occured during Stripe customer metadata update. " . $e->getMessage());
			$body = $e->getJsonBody();
			wcfmvm_create_log("Error details: " . $error_string);
		}
			
		//Grab the charge ID and set it as the transaction ID.
		$txn_id = $customer->id;//$charge->balance_transaction;
		//Grab subscription ID
		$subscr_id = $customer->subscriptions->data[0]->id;
		//The charge ID can be used to retrieve the transaction details using hte following call.
		//\Stripe\Charge::retrieve($charge->id);
		$member_id = sanitize_text_field($_REQUEST['custom']);
		
		$wcfm_membership = get_user_meta( $member_id, 'temp_wcfm_membership', true );
		if( $wcfm_membership ) {
			update_user_meta( $member_id, 'wcfm_membership_paymode', 'stripe' );
			update_user_meta( $member_id, 'wcfm_stripe_subscription_id', $subscr_id );
			$required_approval = get_post_meta( $wcfm_membership, 'required_approval', true ) ? get_post_meta( $wcfm_membership, 'required_approval', true ) : 'no';
			if( $required_approval == 'no' ) {
				$WCFMvm->register_vendor( $member_id );
				$WCFMvm->store_subscription_data( $member_id, 'stripe', $txn_id, 'stripe_reccuring_subscription', 'Completed', $token );
				$WCFMvm->store_subscription_data( $member_id, 'stripe_subs', $subscr_id, 'stripe_reccuring_subscription', 'Completed', $token );
			} else {
				define( 'DOING_WCFM_EMAIL', true );
				
				$member_user = new WP_User(absint($member_id));
				$shop_name = get_user_meta( $member_id, 'store_name', true );
				update_user_meta( $member_id, 'wcfm_membership', $wcfm_membership );
				
				// Vendor Approval Admin Email Notification
				$onapproval_admin_notication_subject = get_option( 'wcfm_membership_onapproval_admin_notication_subject', '{site_name}: A vendor application waiting for approval' );
				$onapproval_admin_notication_content = get_option( 'wcfm_membership_onapproval_admin_notication_content', '' );
				if( !$onapproval_admin_notication_content ) {
					$onapproval_admin_notication_content = "Dear Admin,
																									<br /><br />
																									A new vendor <b>{vendor_name}</b> (Store: <b>{vendor_store}</b>) has just applied to our membership plan <b>{membership_plan}</b>. 
																									<br /><br />
																									Kindly follow the below the link to approve/reject the application.
																									<br /><br />
																									Application: {notification_url} 
																									<br /><br />
																									Thank You";
				}
																 
				$subject = str_replace( '{site_name}', get_bloginfo( 'name' ), $onapproval_admin_notication_subject );
				$message = str_replace( '{dashboard_url}', get_wcfm_url(), $onapproval_admin_notication_content );
				$message = str_replace( '{vendor_name}', $member_user->first_name, $message );
				$message = str_replace( '{vendor_store}', $shop_name, $message );
				$message = str_replace( '{membership_plan}', get_the_title( $wcfm_membership ), $message );
				$message = str_replace( '{notification_url}', get_wcfm_messages_url(), $message );
				$message = apply_filters( 'wcfm_email_content_wrapper', $message, __( 'Vendor Approval', 'wc-multivendor-membership' ) );
				
				wp_mail( get_bloginfo( 'admin_email' ), $subject, $message ); 
				
				// Vendor Approval Admin Desktop Notification
				$author_id = $member_id;
				$author_is_admin = 0;
				$author_is_vendor = 1;
				$message_to = 0;
				$is_notice = 0;
				$is_direct_message = 1;
				$wcfm_messages_type = 'vendor_approval';
			
				$wcfm_messages = sprintf( __( '<b>%s</b> (Store: <b>%s</b>) subscription for <b>%s</b> plan waiting for approval.', 'wc-multivendor-membership' ), $member_user->first_name, $shop_name, get_the_title( $wcfm_membership ) );
				$wcfm_create_message     = "INSERT into {$wpdb->prefix}wcfm_messages 
																	(`message`, `author_id`, `author_is_admin`, `author_is_vendor`, `is_notice`, `is_direct_message`, `message_to`, `message_type`)
																	VALUES
																	('{$wcfm_messages}', {$author_id}, {$author_is_admin}, {$author_is_vendor}, {$is_notice}, {$is_direct_message}, {$message_to}, '{$wcfm_messages_type}')";
															
				$wpdb->query($wcfm_create_message);
				
				$WCFMvm->store_subscription_data( $member_id, 'stripe', $txn_id, 'stripe_reccuring_subscription', 'Completed', $token );
				$WCFMvm->store_subscription_data( $member_id, 'stripe_subs', $subscr_id, 'stripe_reccuring_subscription', 'Completed', $token );
				update_user_meta( $member_id, 'wcfm_subscription_status', 'pending' );
			}
		}
		
		// Reset Membership Session
		if( isset( $_SESSION['wcfm_membership'] ) && isset( $_SESSION['wcfm_membership']['membership'] ) && $_SESSION['wcfm_membership']['membership'] ) {
			unset( $_SESSION['wcfm_membership'] );
		}
		
		wcfmvm_create_log('Transaction data saved.');
		
		//Trigger the stripe IPN processed action hook (so other plugins can can listen for this event).
		do_action('wcfmvm_stripe_ipn_processed', $token);
		
		do_action('wcfmvm_payment_ipn_processed', $token);
		
		//Redirect the user to the return URL (or to the homepage if a return URL is not specified for this payment button).
		$return_url = add_query_arg( 'vmstep', 'thankyou', get_wcfm_membership_url() );
		wcfmvm_create_log("Redirecting customer to: ".$return_url);
		wcfmvm_create_log("End of Stripe Buy Now IPN processing.");
		wp_safe_redirect( $return_url );
	}
}

$swpm_stripe_buy_ipn = new SwpmStripeBuyNowIpnHandler();